@@ -17,11 +17,11 @@ LocalTest - Test functions for L<DBIx::NinjaORM>.
 
 =head1 VERSION
 
-Version 2.4.2
+Version 2.4.3
 
 =cut
 
-our $VERSION = '2.4.2';
+our $VERSION = '2.4.3';
 
 
 =head1 SYNOPSIS
@@ -183,13 +183,13 @@ sub ok_memcache
 {
 	# Verify if Cache::Memcached::Fast is installed.
 	eval 'use Cache::Memcached::Fast';
-	plan( skip_all => 'Cache::Memcached::Fast required to test cache-related features.' )
+	plan( skip_all => 'Cache::Memcached::Fast required to test cache-related features.' ) && exit
 		if $@;
 	
 	my $memcache = LocalTest::get_memcache();
 	
 	# Verify that memcache is configured and running.
-	plan( skip_all => 'Memcache is not running or configured on this machine, cannot test.' )
+	plan( skip_all => 'Memcache is not running or configured on this machine, cannot test.' ) && exit
 		if !defined( $memcache) || !$memcache->set( 'test_ninja_orm', 1, time() + 10 );
 	
 	return $memcache;
